==> download.php?FileName=TerraView-5.1.3-src.tar.gz: TerraView-5.1.3-src/share/terralib/translations/terralib_mod_qt_plugins_vp_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>te::qt::plugins::vp::AggregationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/AggregationAction.cpp" line="42"/>
        <source>Aggregation...</source>
        <translation>Agregação...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/AggregationAction.cpp" line="76"/>
        <location filename="../../../src/terralib/qt/plugins/vp/AggregationAction.cpp" line="85"/>
        <source>Aggregation Result</source>
        <translation>Resultado da Agregação</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/AggregationAction.cpp" line="76"/>
        <source>The operation was concluded successfully. But it has warning(s). Would you like to add the layer to the project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/AggregationAction.cpp" line="85"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::BufferAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="42"/>
        <source>Buffer...</source>
        <translation>Áreas de Influências (Buffer)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="66"/>
        <source>Buffer Result</source>
        <translation>Resultado da Área de Influência (buffer)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="66"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::GeometricOpAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="42"/>
        <source>Geometric Operation...</source>
        <translation>Operação Geométrica...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="66"/>
        <source>Geometric Operation</source>
        <translation>Operação Geométrica</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="66"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::IntersectionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="43"/>
        <source>Intersection...</source>
        <translation>Interseção...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="67"/>
        <source>Intersection Result</source>
        <translation>Resultado da Interseção</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="67"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::LineToPolygonAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="42"/>
        <source>Line to Polygon...</source>
        <translation>Linha para Polígono</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="66"/>
        <source>Line to Polygon Result</source>
        <translation>Resultado de Linha para Polígono</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="66"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::MultipartToSinglepartAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="42"/>
        <source>Multipart To Singlepart...</source>
        <translation>Multi Feição para Única Feição...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="65"/>
        <source>Result</source>
        <translation>Resultado</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="65"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::PolygonToLineAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="42"/>
        <source>Polygon to Line...</source>
        <translation>Polígono para Linha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="65"/>
        <source>Polygon to Line Result</source>
        <translation>Resultado da Polígono para Linha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="65"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::SummarizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/SummarizationAction.cpp" line="40"/>
        <source>Summarization...</source>
        <translation>Sumarizaçãao...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::TransformationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/TransformationAction.cpp" line="40"/>
        <source>Transformation...</source>
        <translation>Transformação...</translation>
    </message>
</context>
</TS>

==> download.php?FileName=TerraView-5.2.3-src.tar.gz: TerraView-5.2.3-src/share/terralib/translations/terralib_mod_qt_plugins_vp_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>te::qt::plugins::vp::AggregationAction</name>
    <message>
        <source>Aggregation...</source>
        <translation type="vanished">Agregação...</translation>
    </message>
    <message>
        <source>Aggregation Result</source>
        <translation type="vanished">Resultado da Agregação</translation>
    </message>
    <message>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="vanished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::BufferAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="42"/>
        <source>Buffer...</source>
        <translation>Áreas de Influências (Buffer)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="66"/>
        <source>Buffer Result</source>
        <translation>Resultado da Área de Influência (buffer)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/BufferAction.cpp" line="66"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::CheckGeomValidityAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/CheckGeomValidityAction.cpp" line="43"/>
        <source>Check Geometry Validity...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::DifferenceAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DifferenceAction.cpp" line="43"/>
        <source>Difference...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DifferenceAction.cpp" line="67"/>
        <source>Difference Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DifferenceAction.cpp" line="67"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="unfinished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::DissolveAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DissolveAction.cpp" line="43"/>
        <source>Dissolve...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DissolveAction.cpp" line="78"/>
        <location filename="../../../src/terralib/qt/plugins/vp/DissolveAction.cpp" line="90"/>
        <source>Dissolve Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DissolveAction.cpp" line="79"/>
        <source>The operation was concluded successfully. But it has warning(s). Would you like to add the layer to the project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/DissolveAction.cpp" line="91"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="unfinished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::GeometricOpAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="42"/>
        <source>Geometric Operation...</source>
        <translation>Operação Geométrica...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="65"/>
        <source>Geometric Operation</source>
        <translation>Operação Geométrica</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/GeometricOpAction.cpp" line="65"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::IdentityAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IdentityAction.cpp" line="43"/>
        <source>Identity...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IdentityAction.cpp" line="78"/>
        <location filename="../../../src/terralib/qt/plugins/vp/IdentityAction.cpp" line="90"/>
        <source>Identity Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IdentityAction.cpp" line="79"/>
        <source>The operation was concluded successfully. But it has warning(s). Would you like to add the layer to the project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IdentityAction.cpp" line="91"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="unfinished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::IntersectionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="43"/>
        <source>Intersection...</source>
        <translation>Interseção...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="67"/>
        <source>Intersection Result</source>
        <translation>Resultado da Interseção</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/IntersectionAction.cpp" line="67"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::LineToPolygonAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="42"/>
        <source>Line to Polygon...</source>
        <translation>Linha para Polígono</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="66"/>
        <source>Line to Polygon Result</source>
        <translation>Resultado de Linha para Polígono</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/LineToPolygonAction.cpp" line="66"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::MergeAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MergeAction.cpp" line="39"/>
        <source>Merge...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MergeAction.cpp" line="62"/>
        <source>Merge Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MergeAction.cpp" line="62"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="unfinished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::MultipartToSinglepartAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="42"/>
        <source>Multipart To Singlepart...</source>
        <translation>Multi Feição para Única Feição...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="65"/>
        <source>Result</source>
        <translation>Resultado</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/MultipartToSinglepartAction.cpp" line="65"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::PolygonToLineAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="42"/>
        <source>Polygon to Line...</source>
        <translation>Polígono para Linha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="65"/>
        <source>Polygon to Line Result</source>
        <translation>Resultado da Polígono para Linha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/PolygonToLineAction.cpp" line="65"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::SummarizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/SummarizationAction.cpp" line="40"/>
        <source>Summarization...</source>
        <translation>Sumarizaçãao...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::TransformationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/TransformationAction.cpp" line="40"/>
        <source>Transformation...</source>
        <translation>Transformação...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::vp::UnionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/UnionAction.cpp" line="39"/>
        <source>Union...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/UnionAction.cpp" line="62"/>
        <source>Union Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/vp/UnionAction.cpp" line="62"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation type="unfinished">A operação foi concluída com êxito. Você gostaria de adicionar a camada para o projeto ?</translation>
    </message>
</context>
</TS>
